==> order-base-2.0.20201223.192615-84-sources.jar: com/rocogz/syy/order/dto/goods/CreateGoodsOrderDto.java <==
package com.rocogz.syy.order.dto.goods;

import com.rocogz.syy.order.constant.OrderConstant;
import com.rocogz.syy.order.dto.invoice.SubmitInvoiceParamDto;
import com.rocogz.syy.order.entity.goods.GoodsOrderDeliveryAddress;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * 创建商品订单 Dto
 * @author ranxiangfu
 * @date 2020/8/19
 */
@Setter @Getter
@Accessors(chain = true)
public class CreateGoodsOrderDto extends SamsungMemberInfoDto {

    //三星生活助手订单的 coupon信息
    private String samsungCouponCode;

    private String samsungCouponType;

    //三星订单 支付过期时间
    private String payExpireTime;
    /**
     *  线上碎屏险 申领人名字
     */
    private String samsungApplierName;

    /**
     *  线上碎屏险 申领日期
     */
    private LocalDate samsungApplyDate;
    /**
     * 管家专项服务商品订单,手机imei号
     */
    private String imei;

    /**
     * 管家专项服务商品订单,手机型号
     */
    private String mobileModel;

    /**
     * 订单编号 [如果是外部生成订单编号，则传入此参数]
     */
    private String orderCode;


    /**
     * 下单来源平台编号，如：三星积分商城  [必传]
     * @see OrderConstant#DICT_PLATFORM_CODE_CENT_MALL
     */
    @NotEmpty
    private String platformCode;

    /**
     * 下单渠道：WAP，PC，管理后台,接口调用 [必传]
     *
     * @see OrderConstant.UserVisitChannel
     */
    @NotEmpty
    private String channel;

    /**
     * 商品编号
     */
    private String goodCode;

    /**
     * 商品名称
     */
    @NotEmpty
    private String goodName;

    /**
     * sku编号
     */
    @NotEmpty
    private String skuCode;

    /**
     * 商品展示图片url
     */
    private String pictureUrl;

    /**
     * 白色,xl
     */
    private String attrValues;

    /**
     * 是否虚拟商品
     */
    @NotNull
    private Boolean virtual;

    /**
     * 虚拟商品类型：卡券(CARD)、 充值(DEPOSIT)、 碎屏险(SCREEN_CRASH_INSURANCE)、 电池券/换壳券(COUPON)
     */
    private String virtualType;

    /**
     * 该商品是否支持花呗分期付款,订单详情发起再次支付时使用
     */
    private Boolean pcreditSupported;

    /**
     * 是否管家服务
     */
    private Boolean butlerService;

    /**
     * 是否三星专区商品
     */
    private Boolean samsungPrefecture;

    /**
     * 碎屏险/手机延保服务:下单模式
     */
    private CreateOrderModeEnum createMode;

    /**
     * 商品供应商编号
     */
    private String supplierCode;

    /**
     * 商品供应商名称
     */
    private String supplierName;

    /**
     * 备注
     */
    private String remark;

    /**
     * 商品支付方式: 纯积分(CENT)、现金抵扣积分(CASH_DEDUCTION)、固定积分+固定现金(CENT_WITH_CASH)
     */
    private String goodPayWay;

    /**
     * 商品订单支付模式 (POINT:积分;  CASH:现金; POINT_AND_CASH:积分+现金)
     * @see com.rocogz.syy.order.constant.OrderConstant.DictGoodsOrderPayWay
     */
    private String payWay;


    /**
     * 现金使用的支付方式：微信/支付宝
     * @see com.rocogz.syy.order.constant.OrderConstant.DictPayWay
     */
    private String cashPayWay;

    /**
     * 花呗分期数
     */
    private Integer hbFqNum;

    /**
     * 积分价
     * （1）"纯积分"支付方式：纯积分
     * （2）"现金抵扣兑换"支付方式：总积分
     * （3）"固定积分+固定现金"支付方式： 固定积分
     */
    private BigDecimal cent;

    /**
     * "现金抵扣兑换"支付方式下：需支付的最少积分
     */
    private BigDecimal minCent;

    /**
     *
     * "固定积分+固定现金" 支付方式下：固定现金价
     */
    private BigDecimal cash;

    /**
     * 运营服务费率: 4表示 4%
     */
    private BigDecimal operationServiceRate;

    /**
     * 结算价
     */
    private BigDecimal settlementPrice;

    /**
     * 商品购买数量
     */
    private Integer quantity;

    /**
     * 充值手机号：如果购买的是 充值虚拟商品(话费,流量)
     */
    private String depositMobile;

    /**
     * 需支付订单现金金额[现金部分]
     */
    private BigDecimal totalCash = BigDecimal.ZERO;

    /**
     * 需支付订单积分 [积分部分]
     */
    private BigDecimal totalCent = BigDecimal.ZERO;

    /**
     * 支付平台收取的 支付现金金额手续费
     */
    private BigDecimal cashFee = BigDecimal.ZERO;

    /**
     * 收货地址信息
     */
    private GoodsOrderDeliveryAddress deliveryAddress;

    //线下碎屏险 发票信息
    private  SubmitInvoiceParamDto invoiceDto;

}

==> order-base-2.0.20210108.022246-99-sources.jar: com/rocogz/syy/order/dto/goods/CreateGoodsOrderDto.java <==
package com.rocogz.syy.order.dto.goods;

import com.rocogz.syy.order.constant.OrderConstant;
import com.rocogz.syy.order.dto.invoice.SubmitInvoiceParamDto;
import com.rocogz.syy.order.entity.goods.GoodsOrderDeliveryAddress;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * 创建商品订单 Dto
 * @author ranxiangfu
 * @date 2020/8/19
 */
@Setter @Getter
@Accessors(chain = true)
public class CreateGoodsOrderDto extends SamsungMemberInfoDto {

    //三星生活助手订单的 coupon信息
    private String samsungCouponCode;

    private String samsungCouponType;

    //三星订单 支付过期时间
    private String payExpireTime;
    /**
     *  线上碎屏险 申领人名字
     */
    private String samsungApplierName;

    /**
     *  线上碎屏险 申领日期
     */
    private LocalDate samsungApplyDate;
    /**
     * 管家专项服务商品订单,手机imei号
     */
    private String imei;

    /**
     * 管家专项服务商品订单,手机型号
     */
    private String mobileModel;

    /**
     * 订单编号 [如果是外部生成订单编号，则传入此参数]
     */
    private String orderCode;


    /**
     * 下单来源平台编号，如：三星积分商城  [必传]
     * @see OrderConstant#DICT_PLATFORM_CODE_CENT_MALL
     */
    @NotEmpty
    private String platformCode;

    /**
     * 下单渠道：WAP，PC，管理后台,接口调用 [必传]
     *
     * @see OrderConstant.UserVisitChannel
     */
    @NotEmpty
    private String channel;

    /**
     * 商品编号
     */
    private String goodCode;

    /**
     * 商品名称
     */
    @NotEmpty
    private String goodName;

    /**
     * sku编号
     */
    @NotEmpty
    private String skuCode;

    /**
     * 商品展示图片url
     */
    private String pictureUrl;

    /**
     * 白色,xl
     */
    private String attrValues;

    /**
     * 是否虚拟商品
     */
    @NotNull
    private Boolean virtual;

    /**
     * 虚拟商品类型：卡券(CARD)、 充值(DEPOSIT)、 碎屏险(SCREEN_CRASH_INSURANCE)、 电池券/换壳券(COUPON)
     */
    private String virtualType;

    /**
     * 该商品是否支持花呗分期付款,订单详情发起再次支付时使用
     */
    private Boolean pcreditSupported;

    /**
     * 是否管家服务
     */
    private Boolean butlerService;

    /**
     * 是否三星专区商品
     */
    private Boolean samsungPrefecture;

    /**
     * 碎屏险/手机延保服务:下单模式
     */
    private CreateOrderModeEnum createMode;

    /**
     * 商品供应商编号
     */
    private String supplierCode;

    /**
     * 商品供应商名称
     */
    private String supplierName;

    /**
     * 备注
     */
    private String remark;

    /**
     * 商品支付方式: 纯积分(CENT)、现金抵扣积分(CASH_DEDUCTION)、固定积分+固定现金(CENT_WITH_CASH)
     */
    private String goodPayWay;

    /**
     * 商品订单支付模式 (POINT:积分;  CASH:现金; POINT_AND_CASH:积分+现金)
     * @see com.rocogz.syy.order.constant.OrderConstant.DictGoodsOrderPayWay
     */
    private String payWay;


    /**
     * 现金使用的支付方式：微信/支付宝
     * @see com.rocogz.syy.order.constant.OrderConstant.DictPayWay
     */
    private String cashPayWay;

    /**
<<<<<<< HEAD
     * 花呗分期数
=======
     * 花呗分期
>>>>>>> f6b669b87cf70081068d04bf81b7c729900b8da3
     */
    private Integer hbFqNum;

    /**
     * 积分价
     * （1）"纯积分"支付方式：纯积分
     * （2）"现金抵扣兑换"支付方式：总积分
     * （3）"固定积分+固定现金"支付方式： 固定积分
     */
    private BigDecimal cent;

    /**
     * "现金抵扣兑换"支付方式下：需支付的最少积分
     */
    private BigDecimal minCent;

    /**
     *
     * "固定积分+固定现金" 支付方式下：固定现金价
     */
    private BigDecimal cash;

    /**
     * 运营服务费率: 4表示 4%
     */
    private BigDecimal operationServiceRate;

    /**
     * 结算价
     */
    private BigDecimal settlementPrice;

    /**
     * 商品购买数量
     */
    private Integer quantity;

    /**
     * 充值手机号：如果购买的是 充值虚拟商品(话费,流量)
     */
    private String depositMobile;

    /**
     * 对接充值方：充值业务类型
     */
    private String chargeBizType;

    /**
     * 对接充值方：充值商品Id
     */
    private String  chargeProductId;


    /**
     * 需支付订单现金金额[现金部分]
     */
    private BigDecimal totalCash = BigDecimal.ZERO;

    /**
     * 需支付订单积分 [积分部分]
     */
    private BigDecimal totalCent = BigDecimal.ZERO;

    /**
     * 支付平台收取的 支付现金金额手续费
     */
    private BigDecimal cashFee = BigDecimal.ZERO;

    /**
     * 收货地址信息
     */
    private GoodsOrderDeliveryAddress deliveryAddress;

    //线下碎屏险 发票信息
    private  SubmitInvoiceParamDto invoiceDto;

}
